@@ -6,9 +6,9 @@ GenOO::Data::File::FASTQ - Object implementing methods for accessing fastq forma
 
 =head1 SYNOPSIS
 
-    # Object that manages a fastq file.
+    # Object that manages a fastq file. 
 
-    # To initialize
+    # To initialize 
     my $file = GenOO::Data::File::FASTQ->new(
         file            => undef,
     );
@@ -27,13 +27,12 @@ GenOO::Data::File::FASTQ - Object implementing methods for accessing fastq forma
 # Let the code begin...
 
 package GenOO::Data::File::FASTQ;
-$GenOO::Data::File::FASTQ::VERSION = '1.5.2';
+
 
 #######################################################################
 #######################   Load External modules   #####################
 #######################################################################
 use Modern::Perl;
-use autodie;
 use Moose;
 use namespace::autoclean;
 
@@ -81,21 +80,15 @@ has '_filehandle' => (
 #######################################################################
 sub next_record {
 	my ($self) = @_;
-
+	
 	my $filehandle = $self->_filehandle;
 	while (my $line = $filehandle->getline) {
 		if ($line =~ /^\@/) {
-			my $id = substr($line,1); 
-			chomp($id); 
-			$id =~ s/\r//g;
-			my $seq = $filehandle->getline;
-			chomp($seq); 
-			$seq =~ s/\r//g;
+			my $id = substr($line,1); chomp($id);
+			my $seq = $filehandle->getline; chomp($seq);
 			$filehandle->getline; #unused line
-			my $quality = $filehandle->getline;
-			chomp($quality); 
-			$quality =~ s/\r//g;
-
+			my $quality = $filehandle->getline; chomp($quality);
+			
 			$self->_inc_records_read_count;
 			return $self->_create_record($id, $seq, $quality);
 		}
@@ -108,26 +101,25 @@ sub next_record {
 #######################################################################
 sub _open_filehandle {
 	my ($self) = @_;
-
+	
 	my $read_mode;
-	my $HANDLE;
 	if (!defined $self->file) {
-		open ($HANDLE, '<-', $self->file);
+		$read_mode = '<-';
 	}
 	elsif ($self->file =~ /\.gz$/) {
-		die 'Cannot open file ' . $self->file . "\n" if ! -e $self->file;
-		open($HANDLE, 'gzip -dc ' . $self->file . ' |');
+		$read_mode = '<:gzip';
 	}
 	else {
-		open ($HANDLE, '<', $self->file);
+		$read_mode = '<';
 	}
-
+	open (my $HANDLE, $read_mode, $self->file);
+	
 	return $HANDLE;
 }
 
 sub _create_record {
 	my ($self, $id, $seq, $quality) = @_;
-
+	
 	return GenOO::Data::File::FASTQ::Record->new(
 		name     => $id,
 		sequence => $seq,
