@@ -76,7 +76,7 @@ GenOO::Gene - Gene object
 # Let the code begin...
 
 package GenOO::Gene;
-$GenOO::Gene::VERSION = '1.5.2';
+
 use Moose;
 use namespace::autoclean;
 
@@ -139,54 +139,6 @@ has 'exonic_regions' => (
 	lazy    => 1
 );
 
-has 'intronic_regions' => (
-	traits  => ['Array'],
-	is      => 'ro',
-	builder => '_build_intronic_regions',
-	clearer => '_clear_intronic_regions',
-	handles => {
-		all_intronic_regions    => 'elements',
-		intronic_regions_count  => 'count',
-	},
-	lazy    => 1
-);
-
-has 'utr5_exonic_regions' => (
-	traits  => ['Array'],
-	is      => 'ro',
-	builder => '_build_utr5_exonic_regions',
-	clearer => '_clear_utr5_exonic_regions',
-	handles => {
-		all_utr5_exonic_regions    => 'elements',
-		utr5_exonic_regions_count  => 'count',
-	},
-	lazy    => 1
-);
-
-has 'cds_exonic_regions' => (
-	traits  => ['Array'],
-	is      => 'ro',
-	builder => '_build_cds_exonic_regions',
-	clearer => '_clear_cds_exonic_regions',
-	handles => {
-		all_cds_exonic_regions    => 'elements',
-		cds_exonic_regions_count  => 'count',
-	},
-	lazy    => 1
-);
-
-has 'utr3_exonic_regions' => (
-	traits  => ['Array'],
-	is      => 'ro',
-	builder => '_build_utr3_exonic_regions',
-	clearer => '_clear_utr3_exonic_regions',
-	handles => {
-		all_utr3_exonic_regions    => 'elements',
-		utr3_exonic_regions_count  => 'count',
-	},
-	lazy    => 1
-);
-
 #######################################################################
 ########################   Interface Methods   ########################
 #######################################################################
@@ -307,50 +259,6 @@ sub exonic_length {
 	return $exonic_length;
 }
 
-sub intronic_length {
-	my ($self) = @_;
-	
-	my $intronic_length = 0;
-	foreach my $region ($self->all_intronic_regions) {
-		$intronic_length += $region->length
-	}
-	
-	return $intronic_length;
-}
-
-sub utr5_exonic_length {
-	my ($self) = @_;
-	
-	my $exonic_length = 0;
-	foreach my $region ($self->all_utr5_exonic_regions) {
-		$exonic_length += $region->length
-	}
-	
-	return $exonic_length;
-}
-
-sub cds_exonic_length {
-	my ($self) = @_;
-	
-	my $exonic_length = 0;
-	foreach my $region ($self->all_cds_exonic_regions) {
-		$exonic_length += $region->length
-	}
-	
-	return $exonic_length;
-}
-
-sub utr3_exonic_length {
-	my ($self) = @_;
-	
-	my $exonic_length = 0;
-	foreach my $region ($self->all_utr3_exonic_regions) {
-		$exonic_length += $region->length
-	}
-	
-	return $exonic_length;
-}
-
 #######################################################################
 #########################   Private methods  ##########################
 #######################################################################
@@ -436,84 +344,12 @@ sub _build_exonic_regions {
 		}
 	}
 	
-	return $self->_merge_exons(\@all_exons);
-}
-
-sub _build_intronic_regions {
-	my ($self) = @_;
-	
-	my @intronic_regions;
-	my @e_regions = sort {$a->start <=> $b->start} $self->all_exonic_regions;
-
-	return [] if @e_regions < 2;
-
-	for (my $i = 0; $i < @e_regions-1; $i++) {
-		push @intronic_regions, GenOO::GenomicRegion->new(
-			strand      => $self->strand,
-			chromosome  => $self->chromosome,
-			start       => $e_regions[$i]->stop + 1,
-			stop        => $e_regions[$i+1]->start - 1,
-		);
-	}
-	
-	return \@intronic_regions;
-}
-
-sub _build_utr5_exonic_regions {
-	my ($self) = @_;
-	
-	my @all_exons;
-	foreach my $transcript (@{$self->transcripts}) {
-		next if !$transcript->is_coding;
-		next if !defined $transcript->utr5;
-		foreach my $exon (@{$transcript->utr5->exons}) {
-			push @all_exons, $exon;
-		}
-	}
-	
-	return $self->_merge_exons(\@all_exons);
-}
-
-sub _build_cds_exonic_regions {
-	my ($self) = @_;
-	
-	my @all_exons;
-	foreach my $transcript (@{$self->transcripts}) {
-		next if !$transcript->is_coding;
-		foreach my $exon (@{$transcript->cds->exons}) {
-			push @all_exons, $exon;
-		}
-	}
-	
-	return $self->_merge_exons(\@all_exons);
-}
-
-sub _build_utr3_exonic_regions {
-	my ($self) = @_;
-	
-	my @all_exons;
-	foreach my $transcript (@{$self->transcripts}) {
-		next if !$transcript->is_coding;
-		next if !defined $transcript->utr3;
-		foreach my $exon (@{$transcript->utr3->exons}) {
-			push @all_exons, $exon;
-		}
-	}
-	
-	return $self->_merge_exons(\@all_exons);
-}
-
-sub _merge_exons {
-	my ($self, $exons) = @_;
-	
-	my @sorted_exons = sort{$a->start <=> $b->start} @$exons;
+	my @sorted_exons = sort{$a->start <=> $b->start} @all_exons;
 	
 	my @exonic_regions;
 	foreach my $exon (@sorted_exons) {
 		my $merge_region = $exonic_regions[-1];
-		if (defined $merge_region and 
-			$merge_region->overlaps_with_offset($exon, 1, 1)) {
-
+		if (defined $merge_region and $merge_region->overlaps($exon)) {
 			$merge_region->stop($exon->stop) if $exon->stop > $merge_region->stop;
 		}
 		else {
@@ -536,13 +372,8 @@ sub _reset {
 	$self->_clear_chromosome;
 	$self->_clear_start;
 	$self->_clear_stop;
-	$self->_clear_exonic_regions;
-	$self->_clear_intronic_regions;
-	$self->_clear_utr5_exonic_regions;
-	$self->_clear_cds_exonic_regions;
-	$self->_clear_utr3_exonic_regions;
 }
 
 __PACKAGE__->meta->make_immutable;
 
-1;
+1;
\ No newline at end of file
