@@ -19,17 +19,9 @@ GenOO::Module::Search::Binary - Module that offers methods for searching in an a
 # Let the code begin...
 
 package GenOO::Module::Search::Binary;
-$GenOO::Module::Search::Binary::VERSION = '1.5.2';
-
-#######################################################################
-#######################   Load External modules   #####################
-#######################################################################
-use Modern::Perl;
+use strict;
 
 
-#######################################################################
-#######################   Interface Functions   #######################
-#######################################################################
 =head2 binary_search_for_value_greater_or_equal
   Arg [1]    : number. The target value
   Arg [2]    : array reference. Array in which the target value is searched.
