@@ -53,7 +53,7 @@ GenOO::Transcript - Corresponds to a gene transcript
 # Let the code begin...
 
 package GenOO::Transcript;
-$GenOO::Transcript::VERSION = '1.5.2';
+
 use Moose;
 use namespace::autoclean;
 
@@ -92,21 +92,21 @@ has 'gene' => (
 );
 
 has 'utr5' => (
-	isa       => 'Maybe[GenOO::Transcript::UTR5]',
+	isa       => 'GenOO::Transcript::UTR5',
 	is        => 'rw',
 	builder   => '_find_or_create_utr5',
 	lazy      => 1
 );
 
 has 'cds' => (
-	isa       => 'Maybe[GenOO::Transcript::CDS]',
+	isa       => 'GenOO::Transcript::CDS',
 	is        => 'rw',
 	builder   => '_find_or_create_cds',
 	lazy      => 1
 );
 
 has 'utr3' => (
-	isa       => 'Maybe[GenOO::Transcript::UTR3]',
+	isa       => 'GenOO::Transcript::UTR3',
 	is        => 'rw',
 	builder   => '_find_or_create_utr3',
 	lazy      => 1
@@ -159,8 +159,6 @@ sub _find_or_create_utr5 {
 		my $utr5_start = ($self->strand == 1) ? $self->start : $self->coding_stop + 1;
 		my $utr5_stop = ($self->strand == 1) ? $self->coding_start - 1 : $self->stop;
 		
-		return undef if $utr5_start > $utr5_stop; # there is no 5'UTR
-		
 		my ($splice_starts, $splice_stops) = _sanitize_splice_coords_within_limits(
 			$self->splice_starts,
 			$self->splice_stops,
@@ -178,8 +176,6 @@ sub _find_or_create_utr5 {
 			transcript    => $self
 		});
 	}
-	
-	return undef;
 }
 
 sub _find_or_create_cds {
@@ -203,8 +199,6 @@ sub _find_or_create_cds {
 			transcript    => $self
 		});
 	}
-	
-	return undef;
 }
 
 sub _find_or_create_utr3 {
@@ -214,8 +208,6 @@ sub _find_or_create_utr3 {
 		my $utr3_start = ($self->strand == 1) ? $self->coding_stop + 1 : $self->start;
 		my $utr3_stop = ($self->strand == 1) ? $self->stop : $self->coding_start - 1;
 		
-		return undef if $utr3_start > $utr3_stop; # there is no 3'UTR
-		
 		my ($splice_starts, $splice_stops) = _sanitize_splice_coords_within_limits(
 			$self->splice_starts,
 			$self->splice_stops,
@@ -233,8 +225,6 @@ sub _find_or_create_utr3 {
 			transcript    => $self
 		});
 	}
-	
-	return undef;
 }
 
 sub _find_biotype {
